@@ -5,38 +5,46 @@ pub(crate) mod validators;
 
 use serde::{Deserialize, Serialize};
 use std::{fs::read_to_string, io::Result, path::Path};
-use validators::{crypto, internet, network};
+use validators::{crypto, internet, network, system};
 
 #[derive(Serialize, Deserialize, Default, Debug, Clone)]
 pub struct Indicators {
+    /// All found URLs
     pub urls: Option<Vec<String>>,
+    /// All found Domains
     pub domains: Option<Vec<String>>,
+    /// All found Email Addresses
     pub emails: Option<Vec<String>>,
+    /// All found IP Addresses
     pub ip_address: Option<Vec<String>>,
+    /// All found Crypto Addresses
     pub crypto: Option<Vec<String>>,
-    pub registry: Option<Vec<String>>,
+    /// All found Registry Keys
+    pub registry_keys: Option<Vec<String>>,
+    /// All found SQL Statements
+    pub sql: Option<Vec<String>>,
 }
 
-pub fn extract_from_file<P: AsRef<Path>>(file: P) -> Result<Option<Indicators>> {
+pub fn from_file<P: AsRef<Path>>(file: P) -> Result<Option<Indicators>> {
     //! Extracts Indicators from a given file
     //!
     //! ## Example Usage
     //! ```rust
-    //! use ioc_extract::extract_from_file;
+    //! use ioc_extract::from_file;
     //!
-    //! let f = "assets/sample.txt";
-    //! println!("{:?}", extract_from_file(f));
+    //! let f = "data/sample.txt";
+    //! println!("{:?}", from_file(f));
     //! ```
     let f = read_to_string(file)?;
-    Ok(extract(&f))
+    Ok(from_str(&f))
 }
 
-pub fn extract(s: &str) -> Option<Indicators> {
+pub fn from_str(s: &str) -> Option<Indicators> {
     //! Extracts Indicators from a given string
     //!
     //! ## Example Usage
     //! ```rust
-    //! use ioc_extract::extract;
+    //! use ioc_extract::from_str;
     //!
     //! let x = "this is an IP address: 192.168.2.11";
     //! println!("{:?}", x);
@@ -46,13 +54,25 @@ pub fn extract(s: &str) -> Option<Indicators> {
     let mut emails = vec![];
     let mut ip_address = vec![];
     let mut crypto_address = vec![];
-    let mut _registry = vec![];
+    let mut registry = vec![];
+    let mut sql = vec![];
 
     // Create a default Indicator object
     let mut iocs = Indicators::default();
 
-    let s = s.split_whitespace().collect::<Vec<&str>>();
-    for x in s {
+    // check for registry keys & sql queries by breaking only newlines
+    // let sr = s.split('\n').collect::<Vec<&str>>();
+    for x in s.split('\n').collect::<Vec<&str>>() {
+        if system::is_registry_key(x) {
+            registry.push(x.to_string())
+        } else if system::is_sql(x) {
+            sql.push(x.to_string())
+        }
+    }
+
+    // check for the rest by breaking newlines, whitespace, tabs, etc...
+    // let s = s.split_whitespace().collect::<Vec<&str>>();
+    for x in s.split_whitespace().collect::<Vec<&str>>() {
         if network::is_ipv_any(x) || network::is_ip_cidr_any(x) {
             ip_address.push(x.to_string())
         } else if crypto::is_cryptocurrency_any(x) {
@@ -71,7 +91,8 @@ pub fn extract(s: &str) -> Option<Indicators> {
         && emails.is_empty()
         && ip_address.is_empty()
         && crypto_address.is_empty()
-        && _registry.is_empty()
+        && registry.is_empty()
+        && sql.is_empty()
     {
         return None;
     }
@@ -101,10 +122,15 @@ pub fn extract(s: &str) -> Option<Indicators> {
         crypto_address.dedup();
         iocs.crypto = Some(crypto_address);
     }
-    if !_registry.is_empty() {
-        _registry.sort();
-        _registry.dedup();
-        iocs.registry = Some(_registry);
+    if !registry.is_empty() {
+        registry.sort();
+        registry.dedup();
+        iocs.registry_keys = Some(registry);
+    }
+    if !sql.is_empty() {
+        sql.sort();
+        sql.dedup();
+        iocs.sql = Some(sql);
     }
 
     // return the result object
@@ -118,11 +144,9 @@ mod tests {
     #[test]
     fn test_extract_ip() {
         let x = "there are ips in this test\n192.168.21.21 and ::ffff:127.0.0.1\nthe cidrs are:\n2001:0DB8:1234::/48 and \n10.0.0.0/33";
-        let ioc = extract(x);
+        let ioc = from_str(x);
         assert!(ioc.is_some());
-        println!("{:?}", ioc);
         let ips = ioc.unwrap().ip_address;
-        println!("{:?}", ips);
         assert!(ips.is_some())
     }
 }
