@@ -1,5 +1,5 @@
+use fancy_regex::Regex;
 use idna::domain_to_ascii;
-use regex::Regex;
 
 lazy_static! {
     static ref DOMAIN: Regex = Regex::new(
@@ -11,13 +11,7 @@ lazy_static! {
         ].join("")
     ).unwrap();
     static ref DOMAIN_WHITELIST: Vec<&'static str> = vec!["localhost"];
-    static ref FILE_EXT: Vec<&'static str> = vec![
-        ".dll", ".exe", ".ini", ".txt", ".doc", "docx", ".xls", "xlsx", ".ppt", "pptx", ".avi", "aiff", ".aif", ".bat",
-        ".bmp", "class", "java", ".csv", ".cvs", "idea", "vscode", ".git", "github", ".dbf", ".dif", ".eps", ".fm3",
-        ".gif", ".hqx", ".html", "html", ".jpg", "jpeg", ".mac", ".map", ".mdb", "mdbx", ".mid", ".midi", ".mov",
-        ".mtb", ".mtw", ".pdf", ".p65", ".t65", ".png", ".psd", ".qxd", ".cdr", ".cdw", ".iso", ".rtf", ".sit", ".tar",
-        ".tif", "tiff", ".wav", "flac", ".wk3", ".mp3", ".wks", ".wpd", ".wp5", ".zip", ".img"
-    ];
+    static ref DOMAINS_EXT: Vec<String> = tld_download::from_db();
     static ref EMAIL: Regex = Regex::new(r"^[A-Za-z0-9\.\+_-]+@[A-Za-z0-9\._-]+\.[a-zA-Z0-9\-]*$").unwrap();
     static ref EMAIL_DOMAIN: Regex = Regex::new(
         &[
@@ -125,7 +119,6 @@ fn is_tld_valid(domain: &str) -> bool {
         // Check to see if TLD contains numbers
         // Before IDN conversion; tld will not have numbers
         let tld = parts[1].to_lowercase();
-        println!("tld: {}", tld);
         if tld
             .chars()
             .map(|c| (c.is_alphabetic() || c == '.'))
@@ -161,9 +154,7 @@ pub fn is_email(value: &str, whitelist: Option<Vec<&str>>) -> bool {
     // Convert to IDN
     let user_part = match domain_to_ascii(user_part) {
         Ok(x) => x,
-        Err(_) => {
-            return false;
-        }
+        Err(_) => return false,
     };
     if user_part.len() > 64 {
         return false;
@@ -171,13 +162,12 @@ pub fn is_email(value: &str, whitelist: Option<Vec<&str>>) -> bool {
     // Convert to IDN
     let domain_part = match domain_to_ascii(domain_part) {
         Ok(x) => x,
-        Err(_) => {
-            return false;
-        }
+        Err(_) => return false,
     };
     let value = format!("{}@{}", user_part, domain_part);
 
-    EMAIL.is_match(&value) && EMAIL_DOMAIN.is_match(&domain_part)
+    EMAIL.is_match(&value).unwrap_or_default()
+        && EMAIL_DOMAIN.is_match(&domain_part).unwrap_or_default()
         || whitelist.contains(&domain_part.as_str())
 }
 
@@ -185,19 +175,13 @@ pub fn is_domain(value: &str) -> bool {
     //! Check if the given value is a Domain Name.
     let x = match domain_to_ascii(value) {
         Ok(x) => x,
-        Err(_) => {
-            return false;
-        }
+        Err(_) => return false,
     };
 
-    let x_len = x.len();
-    if x_len > 4 && FILE_EXT.contains(&&x[x_len - 4..]) {
-        // probable file name found
-        return false
-    }
-
-    if DOMAIN.is_match(&x) {
-        return true
+    if DOMAIN.is_match(&x).unwrap_or_default()
+        && DOMAINS_EXT.iter().any(|suffix| x.ends_with(suffix))
+    {
+        return true;
     }
 
     false
@@ -205,7 +189,7 @@ pub fn is_domain(value: &str) -> bool {
 
 pub fn is_url(value: &str) -> bool {
     //! Check if the given value is a URL.
-    URL.is_match(value)
+    URL.is_match(value).unwrap_or_default()
 }
 
 #[cfg(test)]
